@@ -1,5 +1,5 @@
 package App::pherkin;
-$App::pherkin::VERSION = '0.74';
+$App::pherkin::VERSION = '0.76';
 use strict;
 use warnings;
 
@@ -9,7 +9,7 @@ use Module::Runtime qw(use_module module_notional_filename);
 use List::Util qw(max);
 use Pod::Usage;
 use FindBin qw($RealBin $Script);
-use YAML::Syck;
+use YAML qw( LoadFile );
 use Data::Dumper;
 use File::Spec;
 use Path::Class qw/file dir/;
@@ -36,7 +36,7 @@ App::pherkin - Run Cucumber tests from the command line
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -568,7 +568,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
