@@ -1,12 +1,12 @@
 package TAP::Parser::SourceHandler::Feature;
-$TAP::Parser::SourceHandler::Feature::VERSION = '0.74';
+$TAP::Parser::SourceHandler::Feature::VERSION = '0.76';
 =head1 NAME
 
 TAP::Parser::SourceHandler::Feature - Test::BDD::Cucumber's prove integration
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =cut
 
@@ -32,8 +32,6 @@ TAP::Parser::IteratorFactory->register_handler(__PACKAGE__);
 sub can_handle {
     my ( $class, $source ) = @_;
 
-    #use Data::Printer; p $source;
-
     if (   $source->meta->{'is_file'}
         && $source->meta->{'file'}->{'basename'} =~ m/\.feature$/ )
     {
@@ -48,11 +46,22 @@ sub can_handle {
             my %options = %{ $source->config_for($class) };
             while ( my ( $key, $value ) = each %options ) {
 
-                # Nasty hack
-                if ( length $key > 1 ) {
-                    push( @cmd_line, "--$key", $value );
-                } else {
-                    push( @cmd_line, "-$key", $value );
+                # --feature-option 'tags=@something'
+                # --feature-option 'tags=@somethingelse'
+                #
+                # is passed in %options as:
+                # { ..., tags => [ '@something', '@somethingelse' ], ... }
+                #
+                # Now unfold that back into an argument array as
+                #  --tags @something --tags @somethingelse
+                $value = [ $value ] unless ref $value;
+                for my $v (@$value) {
+                    # Nasty hack
+                    if ( length $key > 1 ) {
+                        push( @cmd_line, "--$key", $v );
+                    } else {
+                        push( @cmd_line, "-$key", $v );
+                    }
                 }
             }
 
@@ -103,6 +112,7 @@ sub make_iterator {
     my $context = context();
     # Without the step to set the handles TAP will end up on STDOUT/STDERR
     $context->hub->format->set_handles([$output_fh, $output_fh]);
+    $context->release;
     $pherkin->harness($harness);
     my $filename = file( $dir . $source->meta->{'file'}->{'basename'} ) . '';
 
@@ -111,7 +121,6 @@ sub make_iterator {
         . ( join '; ', keys %{ $runtime->{'features'} } );
 
     $pherkin->_run_tests( $executor, $feature );
-    $context->release;
 
     close $output_fh;
     $pherkin->_post_run;
