@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber;
-$Test::BDD::Cucumber::VERSION = '0.74';
+$Test::BDD::Cucumber::VERSION = '0.76';
 use strict;
 use warnings;
 1;
@@ -12,7 +12,7 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -26,12 +26,15 @@ version 0.74
    # Or all those /not/ tagged 'slow'
    $ pherkin -l -b --tags ~@slow
 
+   # Fail on missing steps (by default prints as orange output and succeeds tests)
+   $ pherkin -l -b --strict t/
+
 
    # Driving tests using 'prove' integration
-   $ prove --source Feature --ext=.feature t/
+   $ prove --source Feature --ext=.feature examples/
 
    # Driving parallel tests using 'prove'
-   $ prove --source Feature -j 9 --ext=.feature t/
+   $ prove -r --source Feature -j 9 --ext=.feature t/
 
 
 =head1 DESCRIPTION
@@ -135,7 +138,7 @@ Ben Rodgers C<ben@bdr.org>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
