@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Executor;
-$Test::BDD::Cucumber::Executor::VERSION = '0.74';
+$Test::BDD::Cucumber::Executor::VERSION = '0.76';
 =head1 NAME
 
 Test::BDD::Cucumber::Executor - Run through Feature and Harness objects
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 DESCRIPTION
 
@@ -18,13 +18,8 @@ Definitions, and reporting on progress through the passed-in harness.
 use Moo;
 use MooX::HandlesVia;
 use Types::Standard qw( Bool Str ArrayRef HashRef );
-use Clone qw(clone);
 use List::Util qw/first any/;
-use List::MoreUtils qw/pairwise/;
 use Module::Runtime qw/use_module/;
-use Number::Range;
-use Carp qw/croak/;
-our @CARP_NOT;
 
 use Test2::API qw/intercept/;
 
@@ -43,8 +38,6 @@ use Test::BDD::Cucumber::Util;
 use Test::BDD::Cucumber::Model::Result;
 use Test::BDD::Cucumber::Errors qw/parse_error_from_line/;
 
-has '_bail_out' => ( is => 'rw', isa => Bool, default => 0 );
-
 =head1 ATTRIBUTES
 
 =head2 matching
@@ -228,7 +221,6 @@ sub execute_outline {
                     scenario => $outline,
                     background => $background,
                     scenario_stash => {},
-                    outline_state => {},
                     dataset => {},
                 });
         }
@@ -244,8 +236,6 @@ sub execute_outline {
 
     foreach my $rows (@datasets) {
 
-        my $outline_state = {};
-
         foreach my $row (@{$rows->data}) {
 
             my $name = $outline->{name} || "";
@@ -261,11 +251,8 @@ sub execute_outline {
                     scenario => $outline,
                     background => $background,
                     scenario_stash => {},
-                    outline_state => $outline_state,
                     dataset => $row,
                 });
-
-            $outline_state->{'short_circuit'} ||= $self->_bail_out;
         }
     }
 }
@@ -297,10 +284,10 @@ the Harness interface.
 sub _execute_steps {
     my ( $self, $options ) = @_;
     my ( $feature, $feature_stash, $harness, $outline,
-        $scenario_stash, $outline_state, $dataset, $context_defaults )
+        $scenario_stash, $scenario_state, $dataset, $context_defaults )
       = @$options{
         qw/ feature feature_stash harness scenario scenario_stash
-          outline_state dataset context_defaults
+          scenario_state dataset context_defaults
           /
       };
 
@@ -335,11 +322,11 @@ sub _execute_steps {
 
         my $result =
             $self->find_and_dispatch( $context,
-                                      $outline_state->{'short_circuit'}, 0 );
+                                      $scenario_state->{'short_circuit'}, 0 );
 
         # If it didn't pass, short-circuit the rest
         unless ( $result->result eq 'passing' ) {
-            $outline_state->{'short_circuit'}++;
+            $scenario_state->{'short_circuit'}++;
         }
 
     }
@@ -349,7 +336,7 @@ sub _execute_steps {
 
 
 sub _execute_hook_steps {
-    my ( $self, $phase, $context_defaults, $outline_state ) = @_;
+    my ( $self, $phase, $context_defaults, $scenario_state ) = @_;
     my $want_short = ($phase eq 'before');
 
     for my $step ( @{ $self->{'steps'}->{$phase} || [] } ) {
@@ -360,13 +347,13 @@ sub _execute_hook_steps {
         my $result =
             $self->dispatch(
                 $context, $step,
-                ($want_short ? $outline_state->{'short_circuit'} : 0),
+                ($want_short ? $scenario_state->{'short_circuit'} : 0),
                 0 );
 
         # If it didn't pass, short-circuit the rest
         unless ( $result->result eq 'passing' ) {
             if ($want_short) {
-                $outline_state->{'short_circuit'} = 1;
+                $scenario_state->{'short_circuit'} = 1;
             }
         }
     }
@@ -378,12 +365,13 @@ sub _execute_hook_steps {
 sub execute_scenario {
     my ( $self, $options ) = @_;
     my ( $feature, $feature_stash, $harness, $outline, $background_obj,
-        $scenario_stash, $outline_state, $dataset )
+        $scenario_stash, $dataset )
       = @$options{
         qw/ feature feature_stash harness scenario background scenario_stash
-          outline_state dataset
+          dataset
           /
-      };
+    };
+    my $scenario_state = {};
 
     my %context_defaults = (
         executor => $self,    # Held weakly by StepContext
@@ -412,7 +400,7 @@ sub execute_scenario {
     $_->pre_scenario( $outline, $feature_stash, $scenario_stash )
         for @{ $self->extensions };
 
-    $self->_execute_hook_steps( 'before', \%context_defaults, $outline_state );
+    $self->_execute_hook_steps( 'before', \%context_defaults, $scenario_state );
 
     if ($background_obj) {
         $harness->background( $outline, $dataset,
@@ -424,7 +412,7 @@ sub execute_scenario {
                 feature_stash  => $feature_stash,
                 harness        => $harness,
                 scenario_stash => $scenario_stash,
-                outline_state  => $outline_state,
+                scenario_state  => $scenario_state,
                 context_defaults => \%context_defaults,
             }
             );
@@ -438,15 +426,15 @@ sub execute_scenario {
             feature_stash  => $feature_stash,
             harness        => $harness,
             scenario_stash => $scenario_stash,
-            outline_state  => $outline_state,
+            scenario_state  => $scenario_state,
             dataset        => $dataset,
             context_defaults => \%context_defaults,
         });
 
-    $self->_execute_hook_steps( 'after', \%context_defaults, $outline_state );
+    $self->_execute_hook_steps( 'after', \%context_defaults, $scenario_state );
 
     $_->post_scenario( $outline, $feature_stash, $scenario_stash,
-                       $outline_state->{'short_circuit'} )
+                       $scenario_state->{'short_circuit'} )
         for reverse @{ $self->extensions };
 
     $harness->scenario_done( $outline, $dataset );
@@ -514,19 +502,19 @@ sub find_and_dispatch {
       if $short_circuit;
 
     # Try and find a matching step
-    my $step;
+    my $stepdef;
     my $text = $context->text;
     if ($self->matching eq 'first') {
-        $step = first { $text =~ $_->[0] }
+        $stepdef = first { $text =~ $_->[0] }
         @{ $self->{'steps'}->{ $context->verb } || [] },
             @{ $self->{'steps'}->{'step'} || [] };
     }
     else {
-        my @steps = grep { $text =~ $_->[0] }
+        my @stepdefs = grep { $text =~ $_->[0] }
         @{ $self->{'steps'}->{ $context->verb } || [] },
             @{ $self->{'steps'}->{'step'} || [] };
 
-        if (@steps > 1) {
+        if (@stepdefs > 1) {
             my $filename = $context->step->line->document->filename;
             my $line = $context->step->line->number;
             my $msg =
@@ -536,7 +524,7 @@ sub find_and_dispatch {
                        qq{matcher $_->[0] defined at } .
                            (($_->[1]->{source} && $_->[1]->{line})
                             ? "$_->[1]->{source}:$_->[1]->{line}"
-                            : '<unknown>') } @steps);
+                            : '<unknown>') } @stepdefs);
 
             if ($self->matching eq 'relaxed') {
                 warn $msg;
@@ -545,11 +533,11 @@ sub find_and_dispatch {
                 die $msg;
             }
         }
-        $step = shift @steps;
+        $stepdef = shift @stepdefs;
     }
 
     # Deal with the simple case of no-match first of all
-    unless ($step) {
+    unless ($stepdef) {
         my $message =
             "No matching step definition for: "
           . $context->verb . ' '
@@ -559,17 +547,19 @@ sub find_and_dispatch {
         return $result;
     }
 
-    $_->pre_step( $step, $context ) for @{ $self->extensions };
-    my $result = $self->dispatch( $context, $step, 0, $redispatch );
-    $_->post_step( $step, $context, ( $result->result ne 'passing' ), $result )
+    $_->pre_step( $stepdef, $context ) for @{ $self->extensions };
+    my $result = $self->dispatch( $context, $stepdef, 0, $redispatch );
+    $_->post_step( $stepdef, $context,
+                   ( $result->result ne 'passing' ), $result )
       for reverse @{ $self->extensions };
     return $result;
 }
 
-=head2 dispatch
+=head2 dispatch($context, $stepdef, $short_circuit, $redispatch)
 
-Accepts a L<Test::BDD::Cucumber::StepContext> object, and a L<Test::BDD::Cucumber::Step>
-object and executes it.
+Accepts a L<Test::BDD::Cucumber::StepContext> object, and a
+reference to a step definition triplet (verb, metadata hashref, coderef)
+and executes it the coderef.
 
 You can also pass in a boolean 'short-circuit' flag if the Scenario's remaining
 steps should be skipped.
@@ -577,14 +567,14 @@ steps should be skipped.
 =cut
 
 sub dispatch {
-    my ( $self, $context, $step, $short_circuit, $redispatch ) = @_;
+    my ( $self, $context, $stepdef, $short_circuit, $redispatch ) = @_;
 
     return $self->skip_step( $context, 'pending',
         "Short-circuited from previous tests", $redispatch )
       if $short_circuit;
 
     # Execute the step definition
-    my ( $regular_expression, $meta, $coderef ) = @$step;
+    my ( $regular_expression, $meta, $coderef ) = @$stepdef;
 
     my $step_name = $redispatch ? 'sub_step' : 'step';
     my $step_done_name = $step_name . '_done';
@@ -592,9 +582,7 @@ sub dispatch {
     # Say we're about to start it up
     $context->harness->$step_name($context);
 
-    # Store the string position of matches for highlighting
     my @match_locations;
-
     my $stash_keys = join ';', sort keys %{$context->stash};
     # Using `intercept()`, run the step function in an isolated
     # environment -- this should not affect the enclosing scope
@@ -609,9 +597,6 @@ sub dispatch {
         ###TODO: Both intercept() and Test::More::subtest() should
         # be replaced by a specific Hub implementation for T::B::C
         Test::More::subtest( 'execute step', sub {
-            pass(
-                "Starting to execute step: " . $context->text
-                );
 
             # Take a copy of this. Turns out actually matching against it
             # directly causes all sorts of weird-ass heisenbugs which mst has
@@ -624,9 +609,12 @@ sub dispatch {
             # Save the location of matched subgroups for highlighting hijinks
             my @starts = @-;
             my @ends   = @+;
-            @match_locations = pairwise { [ $a, $b ] } @starts, @ends;
+
+            # Store the string position of matches for highlighting
+            @match_locations = map { [ $_, shift @ends ] } @starts;
 
             # OK, actually execute
+            local $@;
             eval {
                 no warnings 'redefine';
 
@@ -640,7 +628,10 @@ sub dispatch {
                 $coderef->($context)
             };
             if ($@) {
-                fail("Step ran successfully", $@);
+                fail("Step ran to completion", "Exception: ", $@);
+            }
+            else {
+                pass("Step ran to completion");
             }
 
             done_testing();
@@ -688,21 +679,13 @@ sub _extract_match_strings {
 
     return unless @match_locations;
 
-    # Consolidate overlaps
-    my $range = Number::Range->new();
-
-    {
-        # Don't want a complain about numbers already in range, as that's
-        # expected for nested matches
-        no warnings;
-        $range->addrange( $_->[0] . '..' . ( $_->[1] - 1 ) )
-          for @match_locations;
-    }
+    my %range =
+        map { $_ => 1 } map { $_->[0] .. ($_->[1] - 1) } @match_locations;
 
     # Walk the string, splitting
     my @parts = ( [ 0, '' ] );
     for ( 0 .. ( ( length $text ) - 1 ) ) {
-        my $to_highlight = $range->inrange($_);
+        my $to_highlight = $range{$_} || 0;
         my $character = substr( $text, $_, 1 );
 
         if ( $parts[-1]->[0] != $to_highlight ) {
@@ -811,7 +794,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
