@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Extension;
-$Test::BDD::Cucumber::Extension::VERSION = '0.74';
+$Test::BDD::Cucumber::Extension::VERSION = '0.76';
 =head1 NAME
 
 Test::BDD::Cucumber::Extension - Abstract superclass for extensions
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 DESCRIPTION
 
@@ -105,12 +105,12 @@ $failure indicates whether any of the steps in the scenario has failed.
 sub pre_scenario  { return; }
 sub post_scenario { return; }
 
-=head2 pre_step($step, $step_context)
+=head2 pre_step($stepdef, $step_context)
 
 Invoked by the Executor before executing each step in $scenario.
 Reports errors by calling croak().
 
-C<$step> contains a reference to an array with step data:
+C<$stepdef> contains a reference to an array with step data:
 
   [ qr//, { meta => $data }, $code ]
 
@@ -128,7 +128,7 @@ Feature, scenario and step (from the feature file) are available as
 
 Note: B<executed> steps, so not called for skipped steps.
 
-=head2 post_step($step, $step_context, $failed, $result)
+=head2 post_step($stepdef, $step_context, $failed, $result)
 
 Invoked by the Executor after each executed step in $scenario.
 Reports errors by calling croak().
@@ -153,7 +153,7 @@ Erik Huelsmann C<ehuels@gmail.com>
 
 =head1 LICENSE
 
-  Copyright 2016-2020, Erik Huelsmann; Licensed under the same terms as Perl
+  Copyright 2016-2021, Erik Huelsmann; Licensed under the same terms as Perl
 
 =cut
 
