@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Harness::TAP;
-$Test::BDD::Cucumber::Harness::TAP::VERSION = '0.74';
+$Test::BDD::Cucumber::Harness::TAP::VERSION = '0.76';
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::TAP - Generate results in TAP format
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 DESCRIPTION
 
@@ -38,8 +38,8 @@ sub feature {
     my ( $self, $feature ) = @_;
 
     my $ctx = context();
-    $ctx->note(join('', $feature->keyword_original, ' ',
-                    $feature->name, "\n",
+    $ctx->note(join(' ', $feature->keyword_original,
+                    ($feature->name || '') . "\n",
                     map { $_->content } @{ $feature->satisfaction }));
     $ctx->release;
 }
@@ -47,8 +47,8 @@ sub feature {
 sub scenario {
     my ( $self, $scenario, $dataset ) = @_;
     my $ctx = context();
-    $ctx->note(join('', $scenario->keyword_original, ' ',
-                    ($scenario->name || ''), "\n",
+    $ctx->note(join(' ', $scenario->keyword_original,
+                    ($scenario->name || '') . "\n",
                     map { $_->content} @{ $scenario->description }));
     $ctx->release;
 }
@@ -62,24 +62,31 @@ sub step_done {
     my $status = $result->result;
 
     my $step = $context->step;
+    my $scenario = $context->scenario;
     my $step_name;
-
     my $ctx = context();
+
+    # when called from a 'before' or 'after' hook, we have context, but no step
+    $ctx->trace->{frame} = [
+        undef,
+        $step ? $step->line->document->filename : $scenario->line->document->filename,
+        $step ? $step->line->number : $scenario->line->number,
+        undef ];
     if ( $context->is_hook ) {
         $status ne 'undefined'
             and $status ne 'pending'
             and $status ne 'passing'
             or do { $ctx->release; return; };
-        $step_name = 'In ' . ucfirst( $context->verb ) . ' Hook';
+        $step_name = ucfirst( $context->verb ) . ' Hook';
     } else {
         $step_name
-            = 'In ' . ucfirst( $step->verb_original ) . ' ' . $context->text;
+            = ucfirst( $step->verb_original ) . ' ' . $context->text;
     }
 
     if ( $status eq 'undefined' || $status eq 'pending' ) {
         if ( $self->fail_skip ) {
             if ( $status eq 'undefined' ) {
-                $ctx->fail( "No matcher for: $step_name",
+                $ctx->fail( "Matcher for: $step_name",
                             $self->_note_step_data($step));
             } else {
                 $ctx->skip( "Test skipped due to failure in previous step",
@@ -129,7 +136,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
