@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::I18n;
-$Test::BDD::Cucumber::I18n::VERSION = '0.74';
+$Test::BDD::Cucumber::I18n::VERSION = '0.76';
 =encoding utf8
 
 =head1 NAME
@@ -8,7 +8,7 @@ Test::BDD::Cucumber::I18N - Internationalization
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 DESCRIPTION
 
@@ -44,24 +44,6 @@ our @EXPORT_OK =
 
 use Test::BDD::Cucumber::I18N::Data;
 
-my $langdefs = _initialize_language_definitions_from_shared_json_file();
-
-sub _initialize_language_definitions_from_shared_json_file {
-
-    # Parse keywords hash for all supported languages from the JSON file
-    my $langdefs = Test::BDD::Cucumber::I18N::Data::language_definitions();
-
-    # strip asterisks from the keyword definitions since they don't work yet
-    for my $language ( keys %$langdefs ) {
-        my $langdef = $langdefs->{$language};
-        for my $key ( keys %$langdef ) {
-            $langdef->{$key} =~ s{[*]\s*[|]}{};
-        }
-    }
-
-    return $langdefs;
-}
-
 =head1 METHODS
 
 =head2 languages
@@ -71,7 +53,7 @@ Get codes of supported languages.
 =cut
 
 sub languages {
-    return keys %$langdefs;
+    return sort keys %Test::BDD::Cucumber::I18N::Data::languages;
 }
 
 =head2 has_language($language)
@@ -83,7 +65,7 @@ abbreviation defined in C<share/i18n.json>.
 
 sub has_language {
     my ($language) = @_;
-    exists $langdefs->{$language};
+    return exists $Test::BDD::Cucumber::I18N::Data::languages{$language};
 }
 
 =head2 langdef($language)
@@ -97,7 +79,7 @@ sub langdef {
     my ($language) = @_;
 
     return unless has_language($language);
-    return $langdefs->{$language};
+    return $Test::BDD::Cucumber::I18N::Data::languages{$language};
 }
 
 =head2 readable_keywords($string, $transform)
@@ -133,9 +115,8 @@ sub keyword_to_subname {
 
 =head1 LANGUAGES
 
-Languages are defined in a JSON-based hash in the __DATA__ section of
-L<Test::BDD::Cucumber::I18N::Data>, and have been lifted from the
-Gherkin distribution.
+Languages are defined in L<Test::BDD::Cucumber::I18N::Data>, and have been
+lifted from the Gherkin distribution.
 
 =head1 AUTHOR
 
@@ -144,7 +125,7 @@ Gregor Goldbach C<glauschwuffel@nomaden.org>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2014-2019, Gregor Goldbach; Licensed under the same terms as Perl
 
 =cut
