@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber::Model::Scenario;
-$Test::BDD::Cucumber::Model::Scenario::VERSION = '0.74';
+$Test::BDD::Cucumber::Model::Scenario::VERSION = '0.76';
 use Moo;
 use Types::Standard qw( Str ArrayRef HashRef Bool InstanceOf );
 
@@ -11,7 +11,7 @@ Test::BDD::Cucumber::Model::Scenario - Model to represent a scenario
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 DESCRIPTION
 
@@ -62,9 +62,13 @@ This (since v0.65 read-only) accessor will be removed upon release of v1.0.
 
 =cut
 
+my $data_warn_count = 0;
+
 sub data {
     # "pseudo" accessor
     my $self = shift;
+    warn 'Scenario "data" accessor is deprecated since 0.65'
+        unless $data_warn_count++; # warn once
     croak 'Scenario "data" accessor is read-only since 0.65' if @_;
 
     return [] unless @{$self->datasets};
@@ -136,7 +140,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2019-2021, Erik Huelsmann
   Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
